@@ -5,7 +5,11 @@
 #include <fstream>
 #include <algorithm>
 
-#include "../exception/exception"
+#ifdef fbb
+    #include <bobcat/exception>
+#else
+    #include "../exception/exception"
+#endif
 
 #include "../endian/endian.h"
 #include "../header/header.h"
