@@ -4,11 +4,15 @@
 #include <vector>
 #include <string>
 
+class Options;
+
 class Classes
 {
-    using Vect = std::vector<std::string>;  
+    using StrVect = std::vector<std::string>;  
 
-    Vect d_classes;         // the classes in CLASSES
+    Options const &d_options;
+
+    StrVect d_classes;      // the classes in CLASSES
     size_t d_nr;            // the sequence nr of the entries in CLASSES,
                             // d_nr 0 is used for the main directory, 
 
@@ -25,7 +29,7 @@ class Classes
 
     private:
         void read();                            // read CLASSES
-        void subdirs(std::string const &list);  // determine all subdirs
+        void subdirs();                         // determine all subdirs
 };
 
 inline size_t Classes::reset()
