@@ -17,7 +17,7 @@ void Modules::addExtern(Path const &extModgcm)
             ch = ':';
     }
                                                 // was: d_external ??
-    d_scan.modVect().push_back(ModData{ modName, ModData::EXTERN, 
+    d_modVect.push_back(ModData{ modName, ModData::EXTERN, 
                                                                 extModgcm });
     
     if (symlink("../" + extModgcm.string(), cacheName)) // new symlink:
