@@ -5,7 +5,7 @@
 
 void Modules::solveUnknown()
 {                               // UNKNOWN modules, but no -external dirs
-    if (unknowns() and not externalDirs()) 
+    if (unknowns() and d_options.noExternals()) 
     {
         emsg << d_unknowns.size() << " UNKNOWN module";
         if (d_unknowns.size() > 1)
@@ -17,7 +17,7 @@ void Modules::solveUnknown()
     if (unkownExternals())
     {
         for (size_t idx: d_unknowns)
-            emsg << "Module " << d_scan.modVect(idx).modName() << 
+            emsg << "Module " << d_modVect[idx].modName() << 
                                                         " not found" << endl;
     }
 }
