@@ -5,10 +5,10 @@
 
 bool Modules::unkownExternals()
 {
-    for (string const &dir: d_external) // visit all external dirs
+    for (string const &dir: d_options.externals()) // visit all external dirs
     {
         if (not inExternal(dir))        // no unknown mod. in d_external[idx]?
-            continue;                   // then try the next one
+            continue;                   // then try the next directory
 
         if (d_unknowns.empty())
             return false;
