@@ -14,10 +14,18 @@ void Scan::definePartition()
 
     imsg << "       defines partition " << matched << endl;
 
-                                    // get the module's index
+                                    // declare the module, get its index
+    d_nameIdx = declare(matched.substr(0, matched.find(':')));
 
-    size_t idx = declare(matched.substr(0, matched.find(':')));
-
-    d_currentIdx = define(matched);
-    d_modVect[idx].imports(d_currentIdx);
+                                    // define the partition Name:Part
+    d_currentIdx = define(matched); // and set d_current
 }
+
+// it's defined but not yet used
+//  d_modVect[idx].imports(d_currentIdx);
+
+
+
+
+
+
