@@ -1,4 +1,4 @@
-inline void DateTime::setMonthNr(int monthNr)
+inline void FBB::DateTime::setMonthNr(int monthNr)
 {
     setMonth(static_cast<int>(monthNr - 1));
 }
