@@ -28,6 +28,11 @@ inline bool Options::precompile() const
     return d_precompileOption;
 }
 
+inline bool Options::quiet() const
+{
+    return d_quiet;
+}
+
 inline bool Options::softLink() const
 {
     return d_softLinkOption;
