@@ -5,7 +5,11 @@
 #include <string>
 #include <iosfwd>
 
-#include "../../tmp/build/arg/arg"
+#ifdef fbb
+    #include <bobcat/arg>
+#else
+    #include "../../tmp/build/arg/arg"
+#endif
 
 namespace FBB
 {
@@ -19,63 +23,64 @@ class Options
     std::string d_spch;
     std::string d_spchGch;
 
+    bool d_all;
     bool d_listOption;
-    bool d_listOnly;
     bool d_precompileOption;
+    bool d_quiet;
     bool d_softLinkOption;
     bool d_topDirOption;
     bool d_topDir;
-    bool d_warn;
+
+    std::string d_extraOptions;     // extra options used with --precompile
 
     bool d_internalOption;
     std::string d_internal;
 
-    bool d_guardOption;
-    std::string d_guard;
-    
     bool d_classesOption;
     std::string d_classes;
 
-    std::string d_required;
-
-    bool d_keepOption;
-    static FBB::Pattern s_keep;
-    static FBB::Pattern s_spec;     // filename spec. pattern for --keep
+    bool d_unusedOption;
+    static FBB::Pattern s_unused;
+    static FBB::Pattern s_spec;     // filename spec. pattern for --unused
 
     public:
         Options();
 
+        bool all() const;
         bool list() const;
-        bool rh() const;
         bool topDir() const;
         std::string const &classes() const;
         std::string const &spch() const;
         std::string const &spchGch() const;
         std::string const &extension() const;       // the targeted extension
-        char const *arg1() const;                   // d_arg[1] with --precomp
-
+        std::string const &extraOptions() const;
+        char const *compilerArg() const;            // d_arg[1] with --precomp
+                                                    // d_arg[2] with --all
         std::string const &internal() const;        // the .ih extension
-        std::string const &guard() const;
-        bool modify(std::string const &filename) const;
-        static bool keep(std::string const &spec);  // #include file spec.
+
+        static bool keep(std::string const &spec);      // deprecated
+        static bool unused(std::string const &spec);    // #include file spec.
         bool precompile() const;
+        bool quiet() const;
         bool softLink() const;
 
     private:
-        bool listOnly(std::string *member, int optChar);    // true: specified
+        bool allOpt();
         bool plainSpchName(char const *option);
         bool spchGch(char const *option, int optChar); 
         void checkOptions();
         void classesOpt();
-        void dotRequired(std::string *member, char const *what, int optChar);
-        void guardOpt();
+        void disallowed(char const *options) const;
+        void ignored(int option, char const *version) const;
         void internalOpt();
-        void keepOpt();
         void listOpt();
         void precompileOpt();
-        void readKeepFile(std::string const &filename);
+        void readUnusedFile(std::string const &filename);
+        void setList(char const *optName);
+        void setSpchGch();
         void softLinkOpt();
         void topDirOpt();
+        void unusedOpt();
 };
 
 #include "options.f"
