@@ -4,4 +4,9 @@
 void Options::precompileOpt()
 {
     d_precompileOption = spchGch("--precompile", 'p');
+
+    if (not d_precompileOption)
+        return;
+
+    disallowed("s");
 }
